|Travis|_ |AppVeyor|_ |Coveralls|_ |pypi_version|_  |doi|_ 

.. |Travis| image:: https://travis-ci.org/pyxem/pyxem.svg?branch=master
.. _Travis: https://travis-ci.org/pyxem/pyxem

.. |AppVeyor| image:: https://ci.appveyor.com/api/projects/status/github/pyxem/pyxem?svg=true&branch=master
.. _AppVeyor: https://ci.appveyor.com/project/dnjohnstone/pyxem/branch/master

.. |Coveralls| image:: https://coveralls.io/repos/github/pyxem/pyxem/badge.svg?branch=master
.. _Coveralls: https://coveralls.io/github/pyxem/pyxem?branch=master

.. |pypi_version| image:: http://img.shields.io/pypi/v/pyxem.svg?style=flat
.. _pypi_version: https://pypi.python.org/pypi/pyxem

.. |doi| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.2649351.svg
.. _doi: https://doi.org/10.5281/zenodo.2649351


pyXem is an open-source python library for crystallographic electron microscopy.

The package defines objects and functions for the analysis of numerous electron diffraction patterns and has been primarily developed as a platform for hybrid diffraction-imaging microscopy based on 4D scanning electron diffraction (SED) data.

**Installation instructions, documentation and tutorial examples are available** `here <https://pyxem.github.io/pyxem-website>`__ .

If analysis using pyXem forms a part of published work please cite the DOI at the top of this page. 

pyXem is released under the GPL v3 license. 
